Crate inherent_pub

Crate inherent_pub 

Attribute Macros

inherent_pub
Make pub methods in the annotated impl Trait for Type block into inherited methods, which can be used without having to import the trait.