Attribute Macros
- inherent_
pub - Make
pubmethods in the annotatedimpl Trait for Typeblock into inherited methods, which can be used without having to import the trait.
pub methods in the annotated impl Trait for Type block into
inherited methods, which can be used without having to import the trait.